@@ -15,12 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks.c,v 1.5 2006/09/13 19:01:37 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
 
 #include "smart-bookmarks-extension.h"
+#include "mozilla-selection.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -33,6 +34,9 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering Smart Bookmarks Extension");
 
+        if (!mozilla_glue_startup ())
+              return 0;
+
 #ifdef ENABLE_NLS
 	/* Initialise the i18n stuff */
 	bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
